| Field          | Value (auto-filled by CI where possible) |        |          |              |
| -------------- | ---------------------------------------- | ------ | -------- | ------------ |
| App            | `my_app`                                 |        |          |              |
| Feature Code   | `F-00123` (Jira / GitHub issue)          |        |          |              |
| Frappe Version | `v15.x.x`                                |        |          |              |
| Branch / Tag   | `version-15-hotfix`                      |        |          |              |
| Last Updated   | `2025-10-10` (ISO)                       |        |          |              |
| Author(s)      | `@gitHandle`                             |        |          |              |
| Reviewer(s)    | `@gitHandle`                             |        |          |              |
| Status         | `Draft`                                  | Review | Released | Deprecated   |

### Used Apps

| App Name       | Org         | Repo                                           | Version |
| -------------- | ----------- | ---------------------------------------------- | ------- |
| Erpnext        | Frappe      | <https://github.com/frappe/erpnext>            | 15.76.0 |
| HRMS           | Frappe      | <https://github.com/frappe/hrms>               | 15.50.0 |
| Print Designer | Frappe      | <https://github.com/frappe/print_designer>     | 1.6.0   |
| Silent Print   | White Stork | <https://github.com/white-stork/silent-print>  | 0.2.0   |
| Business Mode  | White Stork | <https://github.com/white-stork/business-mode> | 0.1.8   |
| Medis          | Medis       | <https://github.com/medis/medis>               | 1.0.0   |

-------------

### Customizations
